@@ -50,12 +50,22 @@
 #' Saves a complete theme file.
 #'
 #' @examples
-#' # Example function
-#' build_rstheme("C:/My Path/", "My theme",
+#' # Example export file paths
+#' # NOTE: These tempfiles are only for the examples. In reality you just call the
+#' # main function and put in your desired path and name directly.
+#' temp_file <- tempfile(fileext = ".rstheme")
+#' file_name <- basename(tools::file_path_sans_ext(temp_file))
+#'
+#' # Example theme
+#' build_rstheme(file_path         = dirname(temp_file),
+#'               theme_name        = file_name,
 #'               editor_background = "#417291",
 #'               editor_headline   = "#602BCA",
 #'               editor_font       = "#C75C48")
 #'
+#' # Manual cleanup for example
+#' unlink(temp_file)
+#'
 #' @export
 build_rstheme <- function(file_path,
                           theme_name        = "qol_green",
@@ -94,11 +104,9 @@ build_rstheme <- function(file_path,
     start_time <- Sys.time()
 
     # Check if folder exists; ... is for testing
-    if (file_path != "..."){
-        if (!dir.exists(file_path)){
-            message(" X ERROR: Directory '", file_path, "' does not exist.")
-            return(invisible(NULL))
-        }
+    if (!dir.exists(file_path) || dirname(file_path) == "."){
+        message(" X ERROR: Directory '", file_path, "' does not exist.")
+        return(invisible(NULL))
     }
 
     # Change main body to light theme if specified
@@ -164,9 +172,7 @@ build_rstheme <- function(file_path,
     # Save file
     path <- ifelse(grepl("/$", file_path), file_path, paste0(file_path, "/"))
 
-    if (file_path != "..."){
-        writeLines(rstheme, paste0(path, theme_name, ".rstheme"))
-    }
+    writeLines(rstheme, paste0(path, theme_name, ".rstheme"))
 
     end_time <- round(difftime(Sys.time(), start_time, units = "secs"), 3)
     message("\n- - - 'build_rstheme' execution time: ", end_time, " seconds\n")
